@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("../Line.js");
+include("scripts/Draw/Line/Line.js");
 include("scripts/ShapeAlgorithms.js");
 
 /**
